@@ -16,14 +16,14 @@ pub enum Urgency {
     Critical,
 }
 
-impl ToString for Urgency {
-    fn to_string(&self) -> String {
+impl std::fmt::Display for Urgency {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
         match self {
-            Urgency::Low => "low".to_string(),
-            Urgency::Medium => "medium".to_string(),
-            Urgency::High => "high".to_string(),
-            Urgency::Emergency => "emergency".to_string(),
-            Urgency::Critical => "critical".to_string(),
+            Urgency::Low => f.write_str("low"),
+            Urgency::Medium => f.write_str("medium"),
+            Urgency::High => f.write_str("high"),
+            Urgency::Emergency => f.write_str("emergency"),
+            Urgency::Critical => f.write_str("critical"),
         }
     }
 }
@@ -456,9 +456,9 @@ macro_rules! ast_node {
             }
         }
 
-        impl ToString for $ast {
-            fn to_string(&self) -> String {
-                self.0.text().to_string()
+        impl std::fmt::Display for $ast {
+            fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+                f.write_str(self.0.text().to_string().as_str())
             }
         }
     };
@@ -606,10 +606,7 @@ impl EntryBuilder {
         }
         if let Some(version) = self.version.as_ref() {
             builder.token(WHITESPACE.into(), " ");
-            builder.token(
-                VERSION.into(),
-                format!("({})", version.to_string()).as_str(),
-            );
+            builder.token(VERSION.into(), format!("({})", version).as_str());
         }
         if let Some(distributions) = self.distributions.as_ref() {
             builder.token(WHITESPACE.into(), " ");
@@ -856,7 +853,7 @@ impl ChangeLog {
     }
 
     pub fn write_to_path(&self, p: &std::path::Path) -> Result<(), Error> {
-        let mut f = std::fs::File::create(p)?;
+        let f = std::fs::File::create(p)?;
         self.write(f)?;
         Ok(())
     }
@@ -925,19 +922,23 @@ impl EntryHeader {
         })
     }
 
-    pub fn set_distributions(&mut self, distributions: Vec<String>) {
+    /// Set distributions for the entry.
+    pub fn set_distributions(&mut self, _distributions: Vec<String>) {
         todo!("set_distributions")
     }
 
-    pub fn set_version(&mut self, version: Version) {
+    /// Set the version for the entry.
+    pub fn set_version(&mut self, _version: Version) {
         todo!("set_version")
     }
 
-    pub fn set_package(&mut self, package: String) {
+    /// Set the package name for the entry.
+    pub fn set_package(&mut self, _package: String) {
         todo!("set_package")
     }
 
-    pub fn set_metadata(&mut self, key: &str, value: &str) {
+    /// Set extra metadata for the entry.
+    pub fn set_metadata(&mut self, _key: &str, _value: &str) {
         todo!("set_metadata")
     }
 
@@ -992,10 +993,12 @@ impl EntryFooter {
             .filter(|s| !s.is_empty())
     }
 
+    /// Set the maintainer for the entry.
     pub fn set_maintainer(&mut self, maintainer: (String, String)) {
         todo!("set_maintainer")
     }
 
+    /// Set email for the entry.
     pub fn set_email(&mut self, email: String) {
         todo!("set_email")
     }
@@ -1007,7 +1010,8 @@ impl EntryFooter {
             .map(|m| m.text())
     }
 
-    pub fn set_timestamp(&mut self, timestamp: String) {
+    /// Set timestamp for the entry.
+    pub fn set_timestamp(&mut self, _timestamp: String) {
         todo!("set_timestamp")
     }
 }
@@ -1737,7 +1741,7 @@ fn test_ensure_first_line() {
 
  -- 
 "#;
-    let mut cl = ChangeLog::read(text.as_bytes()).unwrap();
+    let cl = ChangeLog::read(text.as_bytes()).unwrap();
 
     let entry = cl.entries().next().unwrap();
     assert_eq!(entry.package(), Some("lintian-brush".into()));
